(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    101931,       3249]
NotebookOptionsPosition[     88256,       2785]
NotebookOutlinePosition[     90583,       2841]
CellTagsIndexPosition[     90540,       2838]
WindowTitle->Tutorial A4 - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[" ", "TutorialColorBar",
 CellMargins->{{Inherited, Inherited}, {-5, 0}}],

Cell[TextData[{
 StyleBox[ButtonBox["Mathematica",
  BaseStyle->{"Link", "LinkTrail"},
  ButtonData->"paclet:guide/Mathematica"],
  FontSlant->"Italic"],
 StyleBox[" > ", "LinkTrailSeparator"]
}], "LinkTrail"],

Cell[BoxData[GridBox[{
   {Cell["MODEL BUILDING TUTORIAL", "PacletNameCell"], Cell[TextData[Cell[
    BoxData[
     ActionMenuBox[
      FrameBox["\<\"URL \[RightGuillemet]\"\>",
       StripOnInput->False], {"\<\"ModelBuilding/tutorial/Tutorial A4\"\>":>
      None, "\<\"Copy Mathematica url\"\>":>
      Module[{DocumentationSearch`Private`nb$}, 
       DocumentationSearch`Private`nb$ = NotebookPut[
          Notebook[{
            Cell["ModelBuilding/tutorial/Tutorial A4"]}, Visible -> False]]; 
       SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
       FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
       NotebookClose[DocumentationSearch`Private`nb$]; Null], 
      Delimiter, "\<\"Copy web url\"\>":>
      Module[{DocumentationSearch`Private`nb$}, 
       DocumentationSearch`Private`nb$ = NotebookPut[
          Notebook[{
            Cell[
             BoxData[
              MakeBoxes[
               Hyperlink[
               "http://reference.wolfram.com/mathematica/ModelBuilding/\
tutorial/Tutorial A4.html"], StandardForm]], "Input", TextClipboardType -> 
             "PlainText"]}, Visible -> False]]; 
       SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
       FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
       NotebookClose[DocumentationSearch`Private`nb$]; 
       Null], "\<\"Go to web url\"\>":>FrontEndExecute[{
        NotebookLocate[{
          URL[
           StringJoin[
           "http://reference.wolfram.com/mathematica/", 
            "ModelBuilding/tutorial/Tutorial A4", ".html"]], None}]}]},
      Appearance->None,
      MenuAppearance->Automatic]],
     LineSpacing->{1.4, 0}]], "AnchorBar"]}
  }]], "AnchorBarGrid",
 GridBoxOptions->{GridBoxItemSize->{"Columns" -> {
     Scaled[0.65], {
      Scaled[0.34]}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
   "RowsIndexed" -> {}}},
 CellID->1],

Cell[CellGroupData[{

Cell["Tutorial A4", "Title",
 CellID->509267359],

Cell[BoxData[GridBox[{
   {
    RowBox[{"Discrete", " ", "package"}], Cell[TextData[{
     "A gentle Introduction to the ",
     StyleBox["Mathematica",
      FontSlant->"Italic"],
     " package Discrete, which can be downloaded from ",
     ButtonBox["http://projects.hepforge.org/Discrete/ .",
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["http://projects.hepforge.org/Discrete/"], None},
      ButtonNote->"http://projects.hepforge.org/Discrete/"],
     "\n\nNote:\nThe DiscreteSymmetries package requires an installation of \
GAP - Groups, Algorithms, Programming, which can be obtained from ",
     ButtonBox["http://www.gap-system.org",
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["http://www.gap-system.org"], None},
      ButtonNote->"http://www.gap-system.org"],
     ", as well as the GAP package Repsn, which can be obtained from ",
     ButtonBox["http://www.gap-system.org/Packages/repsn.html .",
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["http://www.gap-system.org/Packages/repsn.html"], None},
      ButtonNote->"http://www.gap-system.org/Packages/repsn.html"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->2096742444],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
 CellID->143330639],

Cell["\<\
We set the current directory to the directory, where this tutorial resides. \
This is only used in the last section, when we save and restore the group \
data.\
\>", "MathCaption",
 CellID->1439991009],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"DirectoryName", "[", 
    RowBox[{"ToFileName", "[", 
     RowBox[{"\"\<FileName\>\"", "/.", 
      RowBox[{"NotebookInformation", "[", 
       RowBox[{"SelectedNotebook", "[", "]"}], "]"}]}], "]"}], "]"}], "]"}], 
  ";"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->1901323266],

Cell["Initialization", "MathCaption",
 CellID->836781195],

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Discrete`ModelBuildingTools`\>\"", "]"}], 
  ";"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->1094073985],

Cell[TextData[{
 "Next, we are going to import the relevant group theory from gap. If the \
executable \"gap\" is in the path, it will be found automatically on a Linux \
system as well as on MacOS. However, if you have installed \"gap\" manually, \
there might not be an executable \"gap\" in the path, but there is a wrapper \
script called gap.sh. If \"gap\" is not found automatically, you can define \
the path to the executable manually by setting ",
 ButtonBox["$MBGAP",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "$MBGAP.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 " accordingly, e.g. ",
 ButtonBox["$MBGAP ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "$MBGAP.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 "= \"/usr/bin/gap\"; "
}], "MathCaption",
 CellID->475686138],

Cell["\<\
Import group A4 from gap. It is the third group in the list of groups of \
order 12.\
\>", "MathCaption",
 CellID->1758440065],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Group", "=", 
   RowBox[{"MBloadGAPSmallGroup", "[", 
    RowBox[{"12", ",", "3"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->168437364],

Cell[CellGroupData[{

Cell[BoxData["\<\"starting GAP generating SmallGroup(12,3)...\"\>"], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->2062099425],

Cell[BoxData["\<\"...finished\"\>"], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->1040756639],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\nStructureDescription:\"\>", 
   "\[InvisibleSpace]", "\<\"A4\"\>", "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["\nStructureDescription:", "A4", "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->1433403627],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 12, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->85591810],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 4, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->1727980696],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4"},
      {"1", "1", "1", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4}, {1, 1, 1, 3}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->993881827],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1"},
      {"1", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
      {"1", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
      {"3", "0", 
       RowBox[{"-", "1"}], "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1}, {1, E^(Complex[0, 
         Rational[-2, 3]] Pi), 1, E^(Complex[0, 
         Rational[2, 3]] Pi)}, {1, E^(Complex[0, 
         Rational[2, 3]] Pi), 1, E^(Complex[0, 
         Rational[-2, 3]] Pi)}, {3, 0, -1, 0}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[9]:=",
 CellID->785615026]
}, Open  ]]
}, Open  ]],

Cell["\<\
If the output stops after \[OpenCurlyDoubleQuote]starting GAP...\
\[CloseCurlyDoubleQuote] and does not show the full output:\
\>", "MathCaption",
 CellID->1326847144],

Cell[CellGroupData[{

Cell[BoxData[{"\<\"starting GAP generating\:f39f...\"\>", \
"\[IndentingNewLine]", 
 RowBox[{"  ", 
  RowBox[{
  ".", "\[IndentingNewLine]", ".", "\[IndentingNewLine]", "."}]}]}], "Print",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellID->1957770746],

Cell[BoxData["\<\"...finished\"\>"], "Print",
 CellID->1006557917]
}, Open  ]],

Cell[TextData[{
 "quit the Mathematica kernel and execute the notebook again. There might be \
a problem with the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " interface to the gap program."
}], "MathCaption",
 CellID->761120582],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetStructureDescription", "[", "Group", "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->75624198],

Cell[BoxData["\<\"A4\"\>"], "Output",
 ImageSize->{21, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->967797854]
}, Open  ]],

Cell["Alternatively, you load the group by using the name in GAP", \
"MathCaption",
 CellID->1384580734],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Group", "=", 
   RowBox[{"MBloadGAPGroup", "[", "\"\<AlternatingGroup(4)\>\"", "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->539685714],

Cell[CellGroupData[{

Cell[BoxData["\<\"starting GAP generating AlternatingGroup(4)...\"\>"], \
"Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->1284912528],

Cell[BoxData["\<\"...finished\"\>"], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->1984843818],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\nStructureDescription:\"\>", 
   "\[InvisibleSpace]", "\<\"A4\"\>", "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["\nStructureDescription:", "A4", "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->1596171049],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 12, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->958403430],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 4, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->2141704109],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4"},
      {"1", "1", "1", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4}, {1, 1, 1, 3}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->642614621],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1"},
      {"1", "1", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
      {"1", "1", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
      {"3", 
       RowBox[{"-", "1"}], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1}, {1, 1, E^(Complex[0, 
         Rational[-2, 3]] Pi), E^(Complex[0, 
         Rational[2, 3]] Pi)}, {1, 1, E^(Complex[0, 
         Rational[2, 3]] Pi), E^(Complex[0, 
         Rational[-2, 3]] Pi)}, {3, -1, 0, 0}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[11]:=",
 CellID->10075688]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "The variable Group contains all informations about Group, which can be \
saved with the usual ",
 ButtonBox["Save",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Save"],
 " function and restored with the function ",
 ButtonBox["Get",
  BaseStyle->"Link",
  ButtonData->"paclet:ref/Get"],
 ". Clebsch-Gordan coefficients are calculated on demand and are also stored \
in Group, because their calculation can be cumbersome for large groups. In \
addition, it is possible to load a group without using GAP by providing the \
representation matrices in a list of a list of matrices, where the first \
element of each list corresponds to the first group element, the second to \
the second, ..."
}], "MathCaption",
 CellID->2046996347],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"MBloadGroupManually", "[", 
   RowBox[{"\"\<A4\>\"", ",", 
    RowBox[{"Group", "[", "\"\<RepMatrices\>\"", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MBgetStructureDescription", "[", "%", "]"}]}], "Input",
 CellLabel->"In[12]:=",
 CellID->1570429468],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 12, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[12]:=",
 CellID->793852236],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 4, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[12]:=",
 CellID->1109539443],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4"},
      {"1", "1", "1", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4}, {1, 1, 1, 3}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[12]:=",
 CellID->824391087],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1"},
      {"1", "1", 
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "/", "3"}]]},
      {"1", "1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "/", "3"}]], 
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]},
      {"3", 
       RowBox[{"-", "1"}], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1}, {
     1, 1, -(-1)^Rational[1, 3], (-1)^Rational[2, 3]}, {
     1, 1, (-1)^Rational[2, 3], -(-1)^Rational[1, 3]}, {3, -1, 0, 0}}], "\n"],
  
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[12]:=",
 CellID->2117361172]
}, Open  ]],

Cell[BoxData["\<\"A4\"\>"], "Output",
 ImageSize->{21, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->332526507]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"MBloadGroupManually", "[", 
  RowBox[{"\"\<A4\>\"", ",", 
   RowBox[{"Group", "[", "\"\<RepMatrices\>\"", "]"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"MBgetStructureDescription", "[", "%", "]"}]}], "Input",
 CellLabel->"In[14]:=",
 CellID->1339887617],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 12, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[14]:=",
 CellID->1199081896],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 4, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[14]:=",
 CellID->117567533],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4"},
      {"1", "1", "1", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4}, {1, 1, 1, 3}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[14]:=",
 CellID->1011990374],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1"},
      {"1", "1", 
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "/", "3"}]]},
      {"1", "1", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"2", "/", "3"}]], 
       RowBox[{"-", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"-", "1"}], ")"}], 
         RowBox[{"1", "/", "3"}]]}]},
      {"3", 
       RowBox[{"-", "1"}], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1}, {
     1, 1, -(-1)^Rational[1, 3], (-1)^Rational[2, 3]}, {
     1, 1, (-1)^Rational[2, 3], -(-1)^Rational[1, 3]}, {3, -1, 0, 0}}], "\n"],
  
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[14]:=",
 CellID->666564186]
}, Open  ]],

Cell[BoxData["Discrete`ModelBuildingTools`Private`Group$991"], "Output",
 ImageSize->{365, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->1645988254],

Cell[BoxData["\<\"A4\"\>"], "Output",
 ImageSize->{21, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->114347022]
}, Open  ]],

Cell[TextData[{
 "Sometimes, it is also useful to generate a group via a set of matrices \
generating the group. This can be done via the function ",
 ButtonBox["MBloadGeneratedGAPGroup",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, 
     "MBloadGeneratedGAPGroup.nb", CharacterEncoding -> "UTF-8"], None}],
 "."
}], "MathCaption",
 CellID->1221950653],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"S4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{"-", "1"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "}"}]}], ";", 
  RowBox[{"T4", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"MBloadGeneratedGAPGroup", "[", 
   RowBox[{"{", 
    RowBox[{"S4", ",", "T4"}], "}"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"MBgetStructureDescription", "[", "%", "]"}]}], "Input",
 CellLabel->"In[16]:=",
 CellID->818755397],

Cell[CellGroupData[{

Cell[BoxData["\<\"starting GAP generating Group([[[0, 1, 0, 0], [1, 0, 0, 0], \
[0, 0, 0, -1], [0, 0, -1, 0]], [[0, 1, 0, 0], [0, 0, 1, 0], [1, 0, 0, 0], [0, \
0, 0, 1]]])...\"\>"], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->197932947],

Cell[BoxData["\<\"...finished\"\>"], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->1074933541],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\nStructureDescription:\"\>", 
   "\[InvisibleSpace]", "\<\"A4\"\>", "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["\nStructureDescription:", "A4", "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->1624292260],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 12, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->1901807959],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 4, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->1434875996],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4"},
      {"1", "1", "1", "3"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4}, {1, 1, 1, 3}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->824968120],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1"},
      {"1", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], "1"},
      {"1", 
       SuperscriptBox["\[ExponentialE]", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], "1"},
      {"3", "0", "0", 
       RowBox[{"-", "1"}]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1}, {1, E^(Complex[0, 
         Rational[-2, 3]] Pi), E^(Complex[0, 
         Rational[2, 3]] Pi), 1}, {1, E^(Complex[0, 
         Rational[2, 3]] Pi), E^(Complex[0, 
         Rational[-2, 3]] Pi), 1}, {3, 0, 0, -1}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[16]:=",
 CellID->2046194104]
}, Open  ]],

Cell[BoxData["\<\"A4\"\>"], "Output",
 ImageSize->{21, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->902721564]
}, Open  ]],

Cell["\<\
A final note: the implementation of the algorithm to calculate the \
Clebsch-Gordan coefficients requires the representations to be unitary! This \
can be automatically checked by passing the option \"CheckUnitarity\"->True \
to any of the functions loading a group. The default is \
\"CheckUnitarity\"->False, because this check is time consuming. Note that \
GAP does not guarantuee to return unitary representations, although they are \
usually unitary. However, for example the GAP-generated representations of A5 \
are not unitary. This can also be explicitly checked with\
\>", "MathCaption",
 CellID->704957072],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"A5Group", "=", 
   RowBox[{"MBloadGAPGroup", "[", 
    RowBox[{"\"\<AlternatingGroup(5)\>\"", ",", 
     RowBox[{"\"\<CheckUnitarity\>\"", "\[Rule]", "True"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"MBisUnitaryRep", "[", 
       RowBox[{"A5Group", ",", "#"}], "]"}], "&"}], ",", 
     RowBox[{"Range", "[", "5", "]"}]}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MBisUnitary", "[", "A5Group", "]"}]}], "Input",
 CellLabel->"In[19]:=",
 CellID->962657460],

Cell[CellGroupData[{

Cell[BoxData["\<\"starting GAP generating AlternatingGroup(5)...\"\>"], \
"Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->514643054],

Cell[BoxData["\<\"...finished\"\>"], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->2049202609],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\\nStructureDescription:\"\>", 
   "\[InvisibleSpace]", "\<\"A5\"\>", "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["\nStructureDescription:", "A5", "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->963370789],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Size of Group:\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Size of Group:", 60, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->44189577],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Number of irreps: \"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Number of irreps: ", 5, "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->684159417],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Dimensions of irreps:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "2", "3", "4", "5"},
      {"1", "3", "3", "4", "5"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Dimensions of irreps:\n", 
   TableForm[{{1, 2, 3, 4, 5}, {1, 3, 3, 4, 5}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->349454454],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Character Table:\\n\"\>", "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"1", "1", "1", "1", "1"},
      {"3", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
      {"3", 
       RowBox[{"-", "1"}], "0", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"4", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}], 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"-", 
           FractionBox[
            RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]}]]}], "-", 
        SuperscriptBox["\[ExponentialE]", 
         FractionBox[
          RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "5"]]}]},
      {"4", "0", "1", 
       RowBox[{"-", "1"}], 
       RowBox[{"-", "1"}]},
      {"5", "1", 
       RowBox[{"-", "1"}], "0", "0"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Character Table:\n", 
   TableForm[{{1, 1, 1, 1, 1}, {3, -1, 0, -E^(Complex[0, 
           Rational[-2, 5]] Pi) - E^(Complex[0, 
         Rational[2, 5]] Pi), -E^(Complex[0, 
           Rational[-4, 5]] Pi) - E^(Complex[0, 
         Rational[4, 5]] Pi)}, {3, -1, 0, -E^(Complex[0, 
           Rational[-4, 5]] Pi) - E^(Complex[0, 
         Rational[4, 5]] Pi), -E^(Complex[0, 
           Rational[-2, 5]] Pi) - E^(Complex[0, 
         Rational[2, 5]] Pi)}, {4, 0, 1, -1, -1}, {5, 1, -1, 0, 0}}], "\n"],
  Editable->False]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->1235869244],

Cell[BoxData["\<\"checking unitarity...\"\>"], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->1490280167],

Cell[BoxData["\<\"There are representations which are not unitary.\\n\"\>"], \
"Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->1779255781],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "False", ",", "False", ",", "False", ",", "False"}], 
  "}"}]], "Print",
 CellLabel->"During evaluation of In[19]:=",
 CellID->629136520]
}, Open  ]],

Cell[BoxData["False"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]=",
 CellID->501037120]
}, Open  ]],

Cell[TextData[{
 "There is one further option of ",
 ButtonBox["MBloadGAPGroup",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBloadGAPGroup.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 ", \"NumericalEvaluate\", which forces all calculations to be done \
numerically, if \"NumericalEvaluate\" is set to True."
}], "MathCaption",
 CellID->1552901339]
}, Open  ]],

Cell[CellGroupData[{

Cell["Simple Calculations", "Subsection",
 CellID->1019526329],

Cell["\<\
After loading the group theory from GAP, we can perform some simple \
calculations...\
\>", "MathCaption",
 CellID->1989085789],

Cell["The size of the group is obtained by executing", "MathCaption",
 CellID->416431915],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetSizeOfGroup", "[", "Group", "]"}]], "Input",
 CellLabel->"In[22]:=",
 CellID->1502371093],

Cell[BoxData["12"], "Output",
 ImageSize->{20, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[22]=",
 CellID->2049582060]
}, Open  ]],

Cell["and the number of representations is", "MathCaption",
 CellID->1529356861],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetNumberOfReps", "[", "Group", "]"}]], "Input",
 CellLabel->"In[23]:=",
 CellID->1438364585],

Cell[BoxData["4"], "Output",
 ImageSize->{13, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->33762722]
}, Open  ]],

Cell["with its dimensions given by", "MathCaption",
 CellID->1866332212],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetDimensionsOfReps", "[", "Group", "]"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->268159436],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1", ",", "3"}], "}"}]], "Output",
 ImageSize->{91, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]=",
 CellID->1950337923]
}, Open  ]],

Cell["and the dimension of the fourth representation in particular", \
"MathCaption",
 CellID->1174343032],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetDimensionOfRep", "[", 
  RowBox[{"Group", ",", "4"}], "]"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->1713952548],

Cell[BoxData["3"], "Output",
 ImageSize->{12, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[25]=",
 CellID->1551152061]
}, Open  ]],

Cell["\<\
The representation matrices of the fourth representation can be obtained via\
\>", "MathCaption",
 CellID->1246066723],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"MatrixForm", ",", 
   RowBox[{"MBgetRepMatrices", "[", 
    RowBox[{"Group", ",", "4"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->1436753276],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztndFvHNUVh6P2n+ChEiovSH1AqFJ56jskQUKC0FKlooXSUquRTGwvdmwL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    "], {{0, 92}, {562, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{562, 92},
  PlotRange->{{0, 562}, {0, 92}}]], "Output",
 ImageSize->{566, 92},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->854583098]
}, Open  ]],

Cell["The character table is obtained by executing", "MathCaption",
 CellID->384209781],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MBgetCharacterTable", "[", "Group", "]"}], "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[27]:=",
 CellID->507477265],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "1", "1", "1"},
     {"1", "1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]], 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]]},
     {"1", "1", 
      SuperscriptBox["\[ExponentialE]", 
       FractionBox[
        RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "\[Pi]"}], "3"]}]]},
     {"3", 
      RowBox[{"-", "1"}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{175, 81},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]//MatrixForm=",
 CellID->371690729]
}, Open  ]],

Cell["\<\
We can form the scalar product of different characters by either giving the \
number of the irreducible representation:\
\>", "MathCaption",
 CellID->572750998],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetCharacterProduct", "[", 
  RowBox[{"Group", ",", "2", ",", "3"}], "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->1499360408],

Cell[BoxData["0"], "Output",
 ImageSize->{12, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->1395380931]
}, Open  ]],

Cell["or by passing a character as argument.", "MathCaption",
 CellID->1598811964],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetCharacterProduct", "[", 
  RowBox[{"Group", ",", "4", ",", 
   RowBox[{"{", 
    RowBox[{"8", ",", "0", ",", "2", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->1029909628],

Cell[BoxData["2"], "Output",
 ImageSize->{12, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->338598327]
}, Open  ]],

Cell["\<\
Show multiplicity of each representation in the Kroneckerproduct 4 x 4\
\>", "Text",
 CellID->1054452775],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetKroneckerProduct", "[", 
  RowBox[{"Group", ",", "4", ",", "4"}], "]"}]], "Input",
 CellLabel->"In[30]:=",
 CellID->543190596],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "1", ",", "1", ",", "2"}], "}"}]], "Output",
 ImageSize->{91, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->1407886723]
}, Open  ]],

Cell["\<\
Show multiplicity of the representation 4 in the Kroneckerproduct 4 x 4\
\>", "Text",
 CellID->470179665],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetMultiplicity", "[", 
  RowBox[{"Group", ",", "4", ",", "4", ",", "4"}], "]"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->1686428777],

Cell[BoxData["2"], "Output",
 ImageSize->{12, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[31]=",
 CellID->895699172]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculations with Clebsch-Gordan coefficients", "Subsection",
 CellID->1615334985],

Cell[TextData[{
 StyleBox["The Clebsch-Gordan coefficients are returned in form of a unitary \
matrix as it is defined in ", "MathCaption"],
 StyleBox[ButtonBox["Physica Status Solidi (b), 1978, 90, 211-224",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://dx.doi.org/10.1002/pssb.2220900123"], None}], "MathCaption"],
 StyleBox[" with ", "MathCaption"],
 StyleBox[ButtonBox["mbgetCGC",
  BaseStyle->"Link",
  ButtonData->"paclet:ModelBuilding/ref/MbgetCGC"], "MathCaption"]
}], "MathCaption",
 CellID->756545932],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"MBgetCGC", "[", 
    RowBox[{"Group", ",", "2", ",", "4"}], "]"}], "//", "MatrixForm"}], 
  "MathCaption"]], "Input",
 CellLabel->"In[32]:=",
 CellID->1793785244],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", 
      RowBox[{"-", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"-", "1"}], ")"}], 
        RowBox[{"1", "/", "3"}]]}], "0"},
     {"0", "0", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"2", "/", "3"}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{167, 51},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]//MatrixForm=",
 CellID->1944317788]
}, Open  ]],

Cell[TextData[{
 "In physics literature, the hermitean conjugate is usually called \
Clebsch-Gordan coefficients, which are obtained by ",
 ButtonBox["MBgetCGCcc",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBgetCGCcc.nb", 
     CharacterEncoding -> "UTF-8"], None}]
}], "MathCaption",
 CellID->1086510402],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"MBgetCGCcc", "[", 
    RowBox[{"Group", ",", "2", ",", "4"}], "]"}], "//", "MatrixForm"}], 
  "MathCaption"]], "Input",
 CellLabel->"In[33]:=",
 CellID->1862474187],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"1", "0", "0"},
     {"0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "+", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}], "2"]}], "0"},
     {"0", "0", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "-", 
       FractionBox[
        RowBox[{"\[ImaginaryI]", " ", 
         SqrtBox["3"]}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{196, 73},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[33]//MatrixForm=",
 CellID->1472104095]
}, Open  ]],

Cell[TextData[{
 "However, it is not necessary to deal with the Clebsch-Gordan coefficients \
directly, because the package allows to multiply representation vectors, \
which we are going to discuss in the following. An irreducible representation \
is created with ",
 ButtonBox["MBgetRepVector",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBgetRepVector.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 " in case of "
}], "MathCaption",
 CellID->1838403912],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Xi]", "=", 
  RowBox[{"MBgetRepVector", "[", "Group", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Chi]", "=", 
  RowBox[{"MBgetRepVector", "[", 
   RowBox[{"Group", ",", "4", ",", "\[Chi]c"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Eta]", "=", 
  RowBox[{"MBgetRepVector", "[", 
   RowBox[{"Group", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", "a"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"2", ",", "b"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"3", ",", "c"}], "}"}]}], "}"}]}], "]"}]}]}], "Input",
 CellLabel->"In[34]:=",
 CellID->733653939],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 ImageSize->{123, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->1514105042],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{243, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[35]=",
 CellID->860668867],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "a1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "b1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "c1", "}"}], "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 ImageSize->{222, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[36]=",
 CellID->2119933326]
}, Open  ]],

Cell["\<\
Additionally, we define the components of \[Chi] to be real, which will be \
used by Simplify, ...\
\>", "MathCaption",
 CellID->436066674],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"$Assumptions", "=", 
  RowBox[{
   RowBox[{"Variables", "[", "\[Chi]", "]"}], "\[Element]", 
   "Reals"}]}]], "Input",
 CellLabel->"In[37]:=",
 CellID->1920272797],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"\[Chi]c1", "|", "\[Chi]c2", "|", "\[Chi]c3"}], ")"}], 
  "\[Element]", "Reals"}]], "Output",
 ImageSize->{183, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[37]=",
 CellID->767339878]
}, Open  ]],

Cell[TextData[{
 "They can be combined in a bigger reducible representation by ",
 ButtonBox["MBJoin",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBJoin.nb", 
     CharacterEncoding -> "UTF-8"], None}]
}], "MathCaption",
 CellID->476066825],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Xi]", "=", 
  RowBox[{"MBJoin", "[", 
   RowBox[{"\[Chi]", ",", "\[Eta]"}], "]"}]}]], "Input",
 CellLabel->"In[38]:=",
 CellID->1467765080],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "a1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "b1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "c1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{342, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[38]=",
 CellID->1097596582]
}, Open  ]],

Cell[TextData[{
 ButtonBox["MBUnion",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBUnion.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 " drops equal combinations in contrast to ",
 ButtonBox["MBJoin",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBJoin.nb", 
     CharacterEncoding -> "UTF-8"], None}]
}], "MathCaption",
 CellID->808796896],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBJoin", "[", 
  RowBox[{"\[Xi]", ",", "\[Xi]"}], "]"}]], "Input",
 CellLabel->"In[39]:=",
 CellID->576316252],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "a1", "}"}], ",", 
     RowBox[{"{", "a1", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "b1", "}"}], ",", 
     RowBox[{"{", "b1", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "c1", "}"}], ",", 
     RowBox[{"{", "c1", "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 ImageSize->{398, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[39]=",
 CellID->1602833484]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBUnion", "[", 
  RowBox[{"\[Xi]", ",", "\[Xi]"}], "]"}]], "Input",
 CellLabel->"In[40]:=",
 CellID->69463102],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", "a1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "b1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", "c1", "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{342, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[40]=",
 CellID->2032257281]
}, Open  ]],

Cell[TextData[{
 "or multiplied with ",
 ButtonBox["MBmultiply",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBmultiply.nb", 
     CharacterEncoding -> "UTF-8"], None}]
}], "MathCaption",
 CellID->2097136614],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBmultiply", "[", 
  RowBox[{"Group", ",", "\[Chi]", ",", "\[Eta]"}], "]"}]], "Input",
 CellLabel->"In[41]:=",
 CellID->1394690369],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"a1", " ", "\[Chi]c1"}], ",", 
       RowBox[{"a1", " ", "\[Chi]c2"}], ",", 
       RowBox[{"a1", " ", "\[Chi]c3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"b1", " ", "\[Chi]c1"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "+", 
          SqrtBox["3"]}], ")"}], " ", "b1", " ", "\[Chi]c2"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "+", 
          SqrtBox["3"]}], ")"}], " ", "b1", " ", "\[Chi]c3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"c1", " ", "\[Chi]c1"}], ",", 
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], "+", 
          SqrtBox["3"]}], ")"}], " ", "c1", " ", "\[Chi]c2"}], ",", 
       RowBox[{
        FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", 
        RowBox[{"(", 
         RowBox[{"\[ImaginaryI]", "+", 
          SqrtBox["3"]}], ")"}], " ", "c1", " ", "\[Chi]c3"}]}], "}"}]}], 
    "}"}]}], "}"}]], "Output",
 ImageSize->{443, 88},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[41]=",
 CellID->786603276]
}, Open  ]],

Cell["\<\
which also allows the multiplication of more than 2 representations\
\>", "MathCaption",
 CellID->323601269],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBmultiply", "[", 
  RowBox[{"Group", ",", 
   RowBox[{"{", 
    RowBox[{"\[Chi]", ",", "\[Chi]", ",", "\[Chi]"}], "}"}]}], "]"}]], "Input",\

 CellLabel->"In[42]:=",
 CellID->200533650],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      SqrtBox["3"], " ", "\[Chi]c1", " ", "\[Chi]c2", " ", "\[Chi]c3"}], 
     "}"}], "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Chi]c1", " ", 
        SuperscriptBox["\[Chi]c2", "2"]}], ",", 
       RowBox[{"\[Chi]c2", " ", 
        SuperscriptBox["\[Chi]c3", "2"]}], ",", 
       RowBox[{
        SuperscriptBox["\[Chi]c1", "2"], " ", "\[Chi]c3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[Chi]c1", " ", 
        SuperscriptBox["\[Chi]c3", "2"]}], ",", 
       RowBox[{
        SuperscriptBox["\[Chi]c1", "2"], " ", "\[Chi]c2"}], ",", 
       RowBox[{
        SuperscriptBox["\[Chi]c2", "2"], " ", "\[Chi]c3"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Chi]c1", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Chi]c1", "2"], "+", 
           SuperscriptBox["\[Chi]c2", "2"], "+", 
           SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
        SqrtBox["3"]], ",", 
       FractionBox[
        RowBox[{"\[Chi]c2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Chi]c1", "2"], "+", 
           SuperscriptBox["\[Chi]c2", "2"], "+", 
           SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
        SqrtBox["3"]], ",", 
       FractionBox[
        RowBox[{"\[Chi]c3", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Chi]c1", "2"], "+", 
           SuperscriptBox["\[Chi]c2", "2"], "+", 
           SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
        SqrtBox["3"]]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
              SqrtBox["3"]}], ")"}]}], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
              SqrtBox["3"]}], ")"}]}], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c1", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
              SqrtBox["3"]}], ")"}]}], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
       RowBox[{
        FractionBox["1", "6"], " ", "\[Chi]c3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
              SqrtBox["3"]}], ")"}]}], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{488, 299},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[42]=",
 CellID->1599585606]
}, Open  ]],

Cell["\<\
Often, it is useful to extract one of the resulting irreducible \
representations\
\>", "MathCaption",
 CellID->1419332408],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBextractOneRep", "[", 
  RowBox[{
   RowBox[{"MBmultiply", "[", 
    RowBox[{"Group", ",", 
     RowBox[{"{", 
      RowBox[{"\[Chi]", ",", "\[Chi]", ",", "\[Chi]", ",", "\[Chi]"}], 
      "}"}]}], "]"}], ",", "1"}], "]"}]], "Input",
 CellLabel->"In[43]:=",
 CellID->1413404838],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["\[Chi]c1", "2"], "+", 
          SuperscriptBox["\[Chi]c2", "2"], "+", 
          SuperscriptBox["\[Chi]c3", "2"]}], ")"}], "2"]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       FractionBox["1", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["\[Chi]c1", "4"], "+", 
         SuperscriptBox["\[Chi]c2", "4"], "-", 
         RowBox[{
          SuperscriptBox["\[Chi]c2", "2"], " ", 
          SuperscriptBox["\[Chi]c3", "2"]}], "+", 
         SuperscriptBox["\[Chi]c3", "4"], "-", 
         RowBox[{
          SuperscriptBox["\[Chi]c1", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["\[Chi]c2", "2"], "+", 
            SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}]}], ")"}]}], "}"}], ",", 
     RowBox[{"{", 
      FractionBox[
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Chi]c2", "2"], " ", 
         SuperscriptBox["\[Chi]c3", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["\[Chi]c1", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["\[Chi]c2", "2"], "+", 
           SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}]}], 
       SqrtBox["3"]], "}"}]}], "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 ImageSize->{447, 105},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[43]=",
 CellID->492354844]
}, Open  ]],

Cell[TextData[{
 "All covariants up to a certain order can be obtained with ",
 ButtonBox["MBgetCovariants",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBgetCovariants.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 " in form of a list of all covariants of first, second, ... order"
}], "MathCaption",
 CellID->1957483307],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetCovariants", "[", 
  RowBox[{"Group", ",", "\[Chi]", ",", "3"}], "]"}]], "Input",
 CellLabel->"In[44]:=",
 CellID->783630378],

Cell[CellGroupData[{

Cell[BoxData["2"], "Print",
 CellLabel->"During evaluation of In[44]:=",
 CellID->1234279535],

Cell[BoxData["3"], "Print",
 CellLabel->"During evaluation of In[44]:=",
 CellID->1584805317]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\[Chi]c1", ",", "\[Chi]c2", ",", "\[Chi]c3"}], "}"}], "}"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Chi]c1", "2"], "+", 
         SuperscriptBox["\[Chi]c2", "2"], "+", 
         SuperscriptBox["\[Chi]c3", "2"]}], 
        SqrtBox["3"]], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        FractionBox["1", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SqrtBox["3"], " ", 
           SuperscriptBox["\[Chi]c1", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c2", "2"]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
             SqrtBox["3"]}], ")"}], " ", 
           SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\[Chi]c2", " ", "\[Chi]c3"}], ",", 
        RowBox[{"\[Chi]c1", " ", "\[Chi]c3"}], ",", 
        RowBox[{"\[Chi]c1", " ", "\[Chi]c2"}]}], "}"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"\[Chi]c1", " ", "\[Chi]c2", " ", "\[Chi]c3"}], "}"}], "}"}], 
     ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Chi]c1", " ", 
          SuperscriptBox["\[Chi]c2", "2"]}], ",", 
         RowBox[{"\[Chi]c2", " ", 
          SuperscriptBox["\[Chi]c3", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["\[Chi]c1", "2"], " ", "\[Chi]c3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"\[Chi]c1", " ", 
          SuperscriptBox["\[Chi]c3", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["\[Chi]c1", "2"], " ", "\[Chi]c2"}], ",", 
         RowBox[{
          SuperscriptBox["\[Chi]c2", "2"], " ", "\[Chi]c3"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         FractionBox[
          RowBox[{"\[Chi]c1", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Chi]c1", "2"], "+", 
             SuperscriptBox["\[Chi]c2", "2"], "+", 
             SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
          SqrtBox["3"]], ",", 
         FractionBox[
          RowBox[{"\[Chi]c2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Chi]c1", "2"], "+", 
             SuperscriptBox["\[Chi]c2", "2"], "+", 
             SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
          SqrtBox["3"]], ",", 
         FractionBox[
          RowBox[{"\[Chi]c3", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["\[Chi]c1", "2"], "+", 
             SuperscriptBox["\[Chi]c2", "2"], "+", 
             SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
          SqrtBox["3"]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
                SqrtBox["3"]}], ")"}]}], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
                SqrtBox["3"]}], ")"}]}], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c1", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
                SqrtBox["3"]}], ")"}]}], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}], ",", 
         RowBox[{
          FractionBox["1", "6"], " ", "\[Chi]c3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", "\[ImaginaryI]"}], "+", 
                SqrtBox["3"]}], ")"}]}], " ", 
             SuperscriptBox["\[Chi]c1", "2"]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "+", 
               SqrtBox["3"]}], ")"}], " ", 
             SuperscriptBox["\[Chi]c2", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["\[Chi]c3", "2"]}]}], ")"}]}]}], "}"}]}], "}"}]}],
     "}"}]}], "}"}]], "Output",
 ImageSize->{494, 427},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[44]=",
 CellID->508095429]
}, Open  ]],

Cell[TextData[{
 "The flavon potential up to a certain order can be obtained with ",
 ButtonBox["MBgetFlavonPotential",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, 
     "MBgetFlavonPotential.nb", CharacterEncoding -> "UTF-8"], None}]
}], "MathCaption",
 CellID->1677877273],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MBgetFlavonPotential", "[", 
  RowBox[{"Group", ",", "\[Chi]", ",", "3", ",", "\[Lambda]"}], 
  "]"}]], "Input",
 CellLabel->"In[45]:=",
 CellID->2090894634],

Cell[CellGroupData[{

Cell[BoxData["2"], "Print",
 CellLabel->"During evaluation of In[45]:=",
 CellID->837379661],

Cell[BoxData["3"], "Print",
 CellLabel->"During evaluation of In[45]:=",
 CellID->377278489]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Lambda]3n1", " ", "\[Chi]c1", " ", "\[Chi]c2", " ", "\[Chi]c3"}],
   "+", 
  FractionBox[
   RowBox[{"\[Lambda]2n1", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Chi]c1", "2"], "+", 
      SuperscriptBox["\[Chi]c2", "2"], "+", 
      SuperscriptBox["\[Chi]c3", "2"]}], ")"}]}], 
   SqrtBox["3"]]}]], "Output",
 ImageSize->{333, 42},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[45]=",
 CellID->1483913076]
}, Open  ]],

Cell[TextData[{
 "Finally, it is useful to obtain a mass matrix given the representations of \
the fermions and flavon fields up to a certain order. This can be done with \
",
 ButtonBox["MBgetMassMatrix",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, "MBgetMassMatrix.nb", 
     CharacterEncoding -> "UTF-8"], None}],
 " for a Dirac mass matrix and ",
 ButtonBox["MBgetMajoranaMassMatrix",
  BaseStyle->"Hyperlink",
  ButtonData->{
    FrontEnd`FileName[{
      ParentDirectory[], "ReferencePages", "Symbols"}, 
     "MBgetMajoranaMassMatrix.nb", CharacterEncoding -> "UTF-8"], None}],
 " in case of a Majorana mass matrix"
}], "MathCaption",
 CellID->1909020233],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MBgetMassMatrix", "[", 
   RowBox[{"Group", ",", 
    RowBox[{"{", "4", "}"}], ",", 
    RowBox[{"{", "4", "}"}], ",", "\[Chi]", ",", "1", ",", "m", ",", "y"}], 
   "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[46]:=",
 CellID->796623246],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n2"}], "+", "ry1n2"}], ")"}], " ",
         "\[Chi]c3"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c2"}], 
       SqrtBox["3"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c3"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n2"}], "+", "ry1n2"}], ")"}], " ",
         "\[Chi]c1"}], 
       SqrtBox["3"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n2"}], "+", "ry1n2"}], ")"}], " ",
         "\[Chi]c2"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c1"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], 
       SqrtBox["3"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{399, 81},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[46]//MatrixForm=",
 CellID->1207489062]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MBgetMajoranaMassMatrix", "[", 
   RowBox[{"Group", ",", 
    RowBox[{"{", "4", "}"}], ",", "\[Chi]", ",", "1", ",", "m", ",", "y"}], 
   "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[47]:=",
 CellID->81371684],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], ")"}]}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c3"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c2"}], 
       SqrtBox["3"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c3"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], ")"}]}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c1"}], 
       SqrtBox["3"]]},
     {
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c2"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "iy1n1"}], "+", "ry1n1"}], ")"}], " ",
         "\[Chi]c1"}], 
       SqrtBox["3"]], 
      FractionBox[
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"\[ImaginaryI]", " ", "imn1"}], "+", "rmn1"}], ")"}]}], 
       SqrtBox["3"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{399, 81},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[47]//MatrixForm=",
 CellID->267813244]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Saving and Loading of the Group Data", "Subsection",
 CellID->519827025],

Cell[TextData[{
 StyleBox["As the calculation of the Clebsch-Gordan coefficients might be \
time-consuming, it is good to save all calculated Clebsch-Gordan coefficients \
(and other group structure related data) and restore it in the next run. This \
can be done with the builtin ", "MathCaption"],
 StyleBox["Mathematica", "MathCaption",
  FontSlant->"Italic"],
 StyleBox[" functions Save and Get", "MathCaption"]
}], "MathCaption",
 CellID->842221038],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SAVE", "=", "\"\<ClebschGordanCoefficients.m\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"SAVE", ",", "Group"}], "]"}], ";"}]}], "Input",
 CellLabel->"In[48]:=",
 CellID->1894383697],

Cell[TextData[StyleBox["Note that Save will always append the definition to \
the file. If you only want to store the latest group structure, then it is \
best to delete the file firstly. Note that Put as well as PutAppend won't \
save the group structure, because it will only save the symbol Group, but not \
the associated data like Group[\"Name\"].", "MathCaption"]], "MathCaption",
 CellID->1448950218],

Cell[BoxData[{
 RowBox[{
  RowBox[{"DeleteFile", "[", "SAVE", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Save", "[", 
   RowBox[{"SAVE", ",", "Group"}], "]"}], ";"}]}], "Input",
 CellLabel->"In[50]:=",
 CellID->1686460171],

Cell[TextData[StyleBox["If the file exists, we are going to load it with Get. \
Otherwise, the group is newly generated via GAP.", "MathCaption"]], \
"MathCaption",
 CellID->743772251],

Cell[BoxData[
 RowBox[{
  RowBox[{"If", "[", 
   RowBox[{
    RowBox[{"FileExistsQ", "[", "SAVE", "]"}], ",", 
    RowBox[{"Get", "[", "SAVE", "]"}], ",", 
    RowBox[{"Group", "=", 
     RowBox[{"mbloadGAPGroup", "[", "\"\<AlternatingGroup(4)\>\"", "]"}]}]}], 
   "]"}], ";"}]], "Input",
 CellLabel->"In[52]:=",
 CellID->347470597],

Cell[TextData[StyleBox["Finally, we are going to delete the file again.", \
"MathCaption"]], "MathCaption",
 CellID->1462835433],

Cell[BoxData[
 RowBox[{
  RowBox[{"DeleteFile", "[", "SAVE", "]"}], ";"}]], "Input",
 CellLabel->"In[53]:=",
 CellID->99065817]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{725, 750},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
WindowTitle->"Tutorial A4 - Wolfram Mathematica",
TaggingRules->{
 "ModificationHighlight" -> False, 
  "Metadata" -> {
   "built" -> "{2011, 11, 8, 11, 26, 7.384559}", "context" -> 
    "ModelBuilding`", 
    "keywords" -> {"Discrete Symmetries Clebsch Gordan coefficients"}, 
    "index" -> True, "label" -> "Model Building Tutorial", "language" -> "en",
     "paclet" -> "ModelBuilding", "status" -> "None", "summary" -> 
    "We set the current directory to the directory, where this tutorial \
resides. This is only used in the last section, when we save and restore the \
group data. Initialization Next, we are going to import the relevant group \
theory from gap. If the executable \"gap\" is in the path, it will be found \
automatically on a Linux system as well as on MacOS. However, if you have \
installed \"gap\" manually, there might not be an executable \"gap\" in the \
path, but there is a wrapper script called gap.sh. If \"gap\" is not found \
automatically, you can define the path to the executable manually by setting \
$MBGAP accordingly, e.g. $MBGAP = \"/usr/bin/gap\"; ", "synonyms" -> {}, 
    "title" -> "Tutorial A4", "type" -> "Tutorial", "uri" -> 
    "ModelBuilding/tutorial/Tutorial A4"}, "LinkTrails" -> "", 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (February 23, 2011)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> "Global`"], 
   Cell[
    StyleData["Output"], CellContext -> "Global`"], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "8.0 for Linux x86 (64-bit) (February 23, 2011)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[604, 21, 78, 1, 3, "TutorialColorBar"],
Cell[685, 24, 209, 6, 19, "LinkTrail"],
Cell[897, 32, 1911, 42, 47, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[2833, 78, 48, 1, 52, "Title",
 CellID->509267359],
Cell[2884, 81, 1198, 27, 151, "DefinitionBox",
 CellID->2096742444],
Cell[CellGroupData[{
Cell[4107, 112, 56, 1, 54, "Subsection",
 CellID->143330639],
Cell[4166, 115, 211, 5, 47, "MathCaption",
 CellID->1439991009],
Cell[4380, 122, 345, 10, 45, "Input",
 CellID->1901323266],
Cell[4728, 134, 57, 1, 32, "MathCaption",
 CellID->836781195],
Cell[4788, 137, 158, 5, 27, "Input",
 CellID->1094073985],
Cell[4949, 144, 944, 22, 77, "MathCaption",
 CellID->475686138],
Cell[5896, 168, 136, 4, 32, "MathCaption",
 CellID->1758440065],
Cell[CellGroupData[{
Cell[6057, 176, 187, 6, 27, "Input",
 CellID->168437364],
Cell[CellGroupData[{
Cell[6269, 186, 142, 2, 23, "Print",
 CellID->2062099425],
Cell[6414, 190, 110, 2, 23, "Print",
 CellID->1040756639],
Cell[6527, 194, 306, 7, 58, "Print",
 CellID->1433403627],
Cell[6836, 203, 275, 7, 41, "Print",
 CellID->85591810],
Cell[7114, 212, 283, 7, 41, "Print",
 CellID->1727980696],
Cell[7400, 221, 889, 23, 70, "Print",
 CellID->993881827],
Cell[8292, 246, 1713, 44, 126, "Print",
 CellID->785615026]
}, Open  ]]
}, Open  ]],
Cell[10032, 294, 177, 4, 32, "MathCaption",
 CellID->1326847144],
Cell[CellGroupData[{
Cell[10234, 302, 259, 7, 75, "Print",
 CellID->1957770746],
Cell[10496, 311, 66, 1, 23, "Print",
 CellID->1006557917]
}, Open  ]],
Cell[10577, 315, 238, 7, 47, "MathCaption",
 CellID->761120582],
Cell[CellGroupData[{
Cell[10840, 326, 125, 3, 27, "Input",
 CellID->75624198],
Cell[10968, 331, 168, 5, 36, "Output",
 CellID->967797854]
}, Open  ]],
Cell[11151, 339, 104, 2, 32, "MathCaption",
 CellID->1384580734],
Cell[CellGroupData[{
Cell[11280, 345, 186, 6, 27, "Input",
 CellID->539685714],
Cell[CellGroupData[{
Cell[11491, 355, 148, 3, 23, "Print",
 CellID->1284912528],
Cell[11642, 360, 111, 2, 23, "Print",
 CellID->1984843818],
Cell[11756, 364, 307, 7, 58, "Print",
 CellID->1596171049],
Cell[12066, 373, 277, 7, 41, "Print",
 CellID->958403430],
Cell[12346, 382, 284, 7, 41, "Print",
 CellID->2141704109],
Cell[12633, 391, 890, 23, 70, "Print",
 CellID->642614621],
Cell[13526, 416, 1713, 44, 126, "Print",
 CellID->10075688]
}, Open  ]]
}, Open  ]],
Cell[15266, 464, 749, 17, 92, "MathCaption",
 CellID->2046996347],
Cell[CellGroupData[{
Cell[16040, 485, 304, 8, 45, "Input",
 CellID->1570429468],
Cell[CellGroupData[{
Cell[16369, 497, 277, 7, 41, "Print",
 CellID->793852236],
Cell[16649, 506, 284, 7, 41, "Print",
 CellID->1109539443],
Cell[16936, 515, 890, 23, 70, "Print",
 CellID->824391087],
Cell[17829, 540, 1580, 47, 112, "Print",
 CellID->2117361172]
}, Open  ]],
Cell[19424, 590, 168, 5, 36, "Output",
 CellID->332526507]
}, Open  ]],
Cell[CellGroupData[{
Cell[19629, 600, 284, 7, 45, "Input",
 CellID->1339887617],
Cell[CellGroupData[{
Cell[19938, 611, 278, 7, 41, "Print",
 CellID->1199081896],
Cell[20219, 620, 283, 7, 41, "Print",
 CellID->117567533],
Cell[20505, 629, 891, 23, 70, "Print",
 CellID->1011990374],
Cell[21399, 654, 1579, 47, 112, "Print",
 CellID->666564186]
}, Open  ]],
Cell[22993, 704, 205, 5, 36, "Output",
 CellID->1645988254],
Cell[23201, 711, 168, 5, 36, "Output",
 CellID->114347022]
}, Open  ]],
Cell[23384, 719, 428, 11, 47, "MathCaption",
 CellID->1221950653],
Cell[CellGroupData[{
Cell[23837, 734, 1144, 33, 79, "Input",
 CellID->818755397],
Cell[CellGroupData[{
Cell[25006, 771, 255, 4, 58, "Print",
 CellID->197932947],
Cell[25264, 777, 111, 2, 23, "Print",
 CellID->1074933541],
Cell[25378, 781, 307, 7, 58, "Print",
 CellID->1624292260],
Cell[25688, 790, 278, 7, 41, "Print",
 CellID->1901807959],
Cell[25969, 799, 284, 7, 41, "Print",
 CellID->1434875996],
Cell[26256, 808, 890, 23, 70, "Print",
 CellID->824968120],
Cell[27149, 833, 1715, 44, 126, "Print",
 CellID->2046194104]
}, Open  ]],
Cell[28879, 880, 168, 5, 36, "Output",
 CellID->902721564]
}, Open  ]],
Cell[29062, 888, 628, 10, 92, "MathCaption",
 CellID->704957072],
Cell[CellGroupData[{
Cell[29715, 902, 613, 18, 79, "Input",
 CellID->962657460],
Cell[CellGroupData[{
Cell[30353, 924, 147, 3, 23, "Print",
 CellID->514643054],
Cell[30503, 929, 111, 2, 23, "Print",
 CellID->2049202609],
Cell[30617, 933, 306, 7, 58, "Print",
 CellID->963370789],
Cell[30926, 942, 276, 7, 41, "Print",
 CellID->44189577],
Cell[31205, 951, 283, 7, 41, "Print",
 CellID->684159417],
Cell[31491, 960, 906, 23, 70, "Print",
 CellID->349454454],
Cell[32400, 985, 2899, 75, 144, "Print",
 CellID->1235869244],
Cell[35302, 1062, 121, 2, 23, "Print",
 CellID->1490280167],
Cell[35426, 1066, 153, 3, 41, "Print",
 CellID->1779255781],
Cell[35582, 1071, 189, 5, 23, "Print",
 CellID->629136520]
}, Open  ]],
Cell[35786, 1079, 163, 5, 36, "Output",
 CellID->501037120]
}, Open  ]],
Cell[35964, 1087, 432, 11, 47, "MathCaption",
 CellID->1552901339]
}, Open  ]],
Cell[CellGroupData[{
Cell[36433, 1103, 62, 1, 54, "Subsection",
 CellID->1019526329],
Cell[36498, 1106, 137, 4, 32, "MathCaption",
 CellID->1989085789],
Cell[36638, 1112, 89, 1, 32, "MathCaption",
 CellID->416431915],
Cell[CellGroupData[{
Cell[36752, 1117, 118, 3, 27, "Input",
 CellID->1502371093],
Cell[36873, 1122, 161, 5, 36, "Output",
 CellID->2049582060]
}, Open  ]],
Cell[37049, 1130, 80, 1, 32, "MathCaption",
 CellID->1529356861],
Cell[CellGroupData[{
Cell[37154, 1135, 119, 3, 27, "Input",
 CellID->1438364585],
Cell[37276, 1140, 158, 5, 36, "Output",
 CellID->33762722]
}, Open  ]],
Cell[37449, 1148, 72, 1, 32, "MathCaption",
 CellID->1866332212],
Cell[CellGroupData[{
Cell[37546, 1153, 122, 3, 27, "Input",
 CellID->268159436],
Cell[37671, 1158, 225, 7, 36, "Output",
 CellID->1950337923]
}, Open  ]],
Cell[37911, 1168, 106, 2, 32, "MathCaption",
 CellID->1174343032],
Cell[CellGroupData[{
Cell[38042, 1174, 144, 4, 27, "Input",
 CellID->1713952548],
Cell[38189, 1180, 160, 5, 36, "Output",
 CellID->1551152061]
}, Open  ]],
Cell[38364, 1188, 128, 3, 32, "MathCaption",
 CellID->1246066723],
Cell[CellGroupData[{
Cell[38517, 1195, 206, 6, 27, "Input",
 CellID->1436753276],
Cell[38726, 1203, 5804, 103, 105, "Output",
 CellID->854583098]
}, Open  ]],
Cell[44545, 1309, 87, 1, 32, "MathCaption",
 CellID->384209781],
Cell[CellGroupData[{
Cell[44657, 1314, 156, 5, 27, "Input",
 CellID->507477265],
Cell[44816, 1321, 1367, 39, 115, "Output",
 CellID->371690729]
}, Open  ]],
Cell[46198, 1363, 170, 4, 32, "MathCaption",
 CellID->572750998],
Cell[CellGroupData[{
Cell[46393, 1371, 156, 4, 27, "Input",
 CellID->1499360408],
Cell[46552, 1377, 160, 5, 36, "Output",
 CellID->1395380931]
}, Open  ]],
Cell[46727, 1385, 82, 1, 32, "MathCaption",
 CellID->1598811964],
Cell[CellGroupData[{
Cell[46834, 1390, 225, 6, 27, "Input",
 CellID->1029909628],
Cell[47062, 1398, 159, 5, 36, "Output",
 CellID->338598327]
}, Open  ]],
Cell[47236, 1406, 115, 3, 32, "Text",
 CellID->1054452775],
Cell[CellGroupData[{
Cell[47376, 1413, 155, 4, 27, "Input",
 CellID->543190596],
Cell[47534, 1419, 225, 7, 36, "Output",
 CellID->1407886723]
}, Open  ]],
Cell[47774, 1429, 115, 3, 32, "Text",
 CellID->470179665],
Cell[CellGroupData[{
Cell[47914, 1436, 162, 4, 27, "Input",
 CellID->1686428777],
Cell[48079, 1442, 159, 5, 36, "Output",
 CellID->895699172]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48287, 1453, 88, 1, 54, "Subsection",
 CellID->1615334985],
Cell[48378, 1456, 523, 12, 47, "MathCaption",
 CellID->756545932],
Cell[CellGroupData[{
Cell[48926, 1472, 210, 7, 26, "Input",
 CellID->1793785244],
Cell[49139, 1481, 1004, 32, 85, "Output",
 CellID->1944317788]
}, Open  ]],
Cell[50158, 1516, 385, 10, 47, "MathCaption",
 CellID->1086510402],
Cell[CellGroupData[{
Cell[50568, 1530, 212, 7, 26, "Input",
 CellID->1862474187],
Cell[50783, 1539, 1088, 35, 107, "Output",
 CellID->1472104095]
}, Open  ]],
Cell[51886, 1577, 539, 13, 62, "MathCaption",
 CellID->1838403912],
Cell[CellGroupData[{
Cell[52450, 1594, 638, 19, 62, "Input",
 CellID->733653939],
Cell[53091, 1615, 302, 11, 36, "Output",
 CellID->1514105042],
Cell[53396, 1628, 391, 14, 36, "Output",
 CellID->860668867],
Cell[53790, 1644, 395, 14, 36, "Output",
 CellID->2119933326]
}, Open  ]],
Cell[54200, 1661, 149, 4, 32, "MathCaption",
 CellID->436066674],
Cell[CellGroupData[{
Cell[54374, 1669, 187, 6, 27, "Input",
 CellID->1920272797],
Cell[54564, 1677, 276, 9, 39, "Output",
 CellID->767339878]
}, Open  ]],
Cell[54855, 1689, 319, 9, 32, "MathCaption",
 CellID->476066825],
Cell[CellGroupData[{
Cell[55199, 1702, 165, 5, 27, "Input",
 CellID->1467765080],
Cell[55367, 1709, 485, 17, 36, "Output",
 CellID->1097596582]
}, Open  ]],
Cell[55867, 1729, 501, 15, 32, "MathCaption",
 CellID->808796896],
Cell[CellGroupData[{
Cell[56393, 1748, 134, 4, 27, "Input",
 CellID->576316252],
Cell[56530, 1754, 757, 26, 54, "Output",
 CellID->1602833484]
}, Open  ]],
Cell[CellGroupData[{
Cell[57324, 1785, 134, 4, 27, "Input",
 CellID->69463102],
Cell[57461, 1791, 485, 17, 36, "Output",
 CellID->2032257281]
}, Open  ]],
Cell[57961, 1811, 286, 9, 32, "MathCaption",
 CellID->2097136614],
Cell[CellGroupData[{
Cell[58272, 1824, 155, 4, 27, "Input",
 CellID->1394690369],
Cell[58430, 1830, 1601, 48, 109, "Output",
 CellID->786603276]
}, Open  ]],
Cell[60046, 1881, 118, 3, 32, "MathCaption",
 CellID->323601269],
Cell[CellGroupData[{
Cell[60189, 1888, 210, 7, 27, "Input",
 CellID->200533650],
Cell[60402, 1897, 6269, 187, 320, "Output",
 CellID->1599585606]
}, Open  ]],
Cell[66686, 2087, 133, 4, 32, "MathCaption",
 CellID->1419332408],
Cell[CellGroupData[{
Cell[66844, 2095, 303, 9, 27, "Input",
 CellID->1413404838],
Cell[67150, 2106, 1647, 51, 126, "Output",
 CellID->492354844]
}, Open  ]],
Cell[68812, 2160, 404, 10, 47, "MathCaption",
 CellID->1957483307],
Cell[CellGroupData[{
Cell[69241, 2174, 154, 4, 27, "Input",
 CellID->783630378],
Cell[CellGroupData[{
Cell[69420, 2182, 93, 2, 23, "Print",
 CellID->1234279535],
Cell[69516, 2186, 93, 2, 23, "Print",
 CellID->1584805317]
}, Open  ]],
Cell[69624, 2191, 8883, 257, 448, "Output",
 CellID->508095429]
}, Open  ]],
Cell[78522, 2451, 351, 9, 32, "MathCaption",
 CellID->1677877273],
Cell[CellGroupData[{
Cell[78898, 2464, 181, 5, 27, "Input",
 CellID->2090894634],
Cell[CellGroupData[{
Cell[79104, 2473, 92, 2, 23, "Print",
 CellID->837379661],
Cell[79199, 2477, 92, 2, 23, "Print",
 CellID->377278489]
}, Open  ]],
Cell[79306, 2482, 496, 16, 63, "Output",
 CellID->1483913076]
}, Open  ]],
Cell[79817, 2501, 739, 19, 62, "MathCaption",
 CellID->1909020233],
Cell[CellGroupData[{
Cell[80581, 2524, 282, 8, 27, "Input",
 CellID->796623246],
Cell[80866, 2534, 2289, 77, 115, "Output",
 CellID->1207489062]
}, Open  ]],
Cell[CellGroupData[{
Cell[83192, 2616, 254, 7, 27, "Input",
 CellID->81371684],
Cell[83449, 2625, 2471, 83, 115, "Output",
 CellID->267813244]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[85969, 2714, 78, 1, 54, "Subsection",
 CellID->519827025],
Cell[86050, 2717, 454, 9, 62, "MathCaption",
 CellID->842221038],
Cell[86507, 2728, 261, 8, 45, "Input",
 CellID->1894383697],
Cell[86771, 2738, 407, 5, 62, "MathCaption",
 CellID->1448950218],
Cell[87181, 2745, 238, 7, 45, "Input",
 CellID->1686460171],
Cell[87422, 2754, 184, 3, 32, "MathCaption",
 CellID->743772251],
Cell[87609, 2759, 332, 10, 45, "Input",
 CellID->347470597],
Cell[87944, 2771, 128, 2, 32, "MathCaption",
 CellID->1462835433],
Cell[88075, 2775, 127, 4, 27, "Input",
 CellID->99065817]
}, Open  ]]
}, Open  ]],
Cell[88229, 2783, 23, 0, 42, "FooterCell"]
}
]
*)

(* End of internal cache information *)

